@@ -11,7 +11,8 @@ from phables_utils import (component_utils, edge_graph_utils, flow_utils,
 from phables_utils.coverage_utils import (get_junction_pe_coverage,
                                           get_unitig_coverage)
 from phables_utils.genome_utils import GenomeComponent, GenomePath
-from phables_utils.output_utils import (write_component_info, write_path,
+from phables_utils.output_utils import (write_component_info,
+                                        write_component_phrog_info, write_path,
                                         write_path_fasta,
                                         write_res_genome_info, write_unitigs)
 from tqdm import tqdm
@@ -19,7 +20,7 @@ from tqdm import tqdm
 __author__ = "Vijini Mallawaarachchi"
 __copyright__ = "Copyright 2022, Phables Project"
 __license__ = "MIT"
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 __maintainer__ = "Vijini Mallawaarachchi"
 __email__ = "viji.mallawaarachchi@gmail.com"
 __status__ = "Development"
@@ -31,7 +32,6 @@ MAX_VAL = sys.maxsize
 
 
 def main():
-
     # Get arguments
     # ----------------------------------------------------------------------
     graph = snakemake.params.graph
@@ -39,13 +39,13 @@ def main():
     bampath = snakemake.params.bampath
     hmmout = snakemake.params.hmmout
     phrogs = snakemake.params.phrogs
-    minlength = snakemake.params.minlength
-    mincov = snakemake.params.mincov
-    compcount = snakemake.params.compcount
-    maxpaths = snakemake.params.maxpaths
-    mgfrac = snakemake.params.mgfrac
-    alignscore = snakemake.params.alignscore
-    seqidentity = snakemake.params.seqidentity
+    minlength = int(snakemake.params.minlength)
+    mincov = int(snakemake.params.mincov)
+    compcount = int(snakemake.params.compcount)
+    maxpaths = int(snakemake.params.maxpaths)
+    mgfrac = float(snakemake.params.mgfrac)
+    evalue = float(snakemake.params.evalue)
+    seqidentity = float(snakemake.params.seqidentity)
     output = snakemake.params.output
     log = snakemake.params.log
 
@@ -85,7 +85,7 @@ def main():
     logger.info(f"Minimum unitig count to consider a component: {compcount}")
     logger.info(f"Maximum number of paths to resolve for a component: {maxpaths}")
     logger.info(f"Length threshold to consider single copy marker genes: {mgfrac}")
-    logger.info(f"Minimum alignment score for phrog annotations: {alignscore}")
+    logger.info(f"Maximum e-value for phrog annotations: {evalue}")
     logger.info(f"Minimum sequence identity for phrog annotations: {seqidentity}")
     logger.info(f"Output folder: {output}")
 
@@ -120,11 +120,13 @@ def main():
 
     # Get unitigs with PHROGs
     # ----------------------------------------------------------------------
-    unitig_phrogs = gene_utils.get_phrog_unitigs(phrogs, alignscore, seqidentity)
+    unitig_phrogs, phrog_dict = gene_utils.get_phrog_unitigs(
+        phrogs, evalue, seqidentity
+    )
 
     # Get components with viral bubbles
     # ----------------------------------------------------------------------
-    pruned_vs = component_utils.get_components(
+    pruned_vs, comp_phrogs = component_utils.get_components(
         assembly_graph,
         unitig_names,
         smg_unitigs,
@@ -132,6 +134,7 @@ def main():
         circular,
         edges_lengths,
         minlength,
+        phrog_dict,
     )
     logger.info(f"Total number of components found: {len(pruned_vs)}")
 
@@ -165,7 +168,6 @@ def main():
     phage_like_edges = set()
 
     for my_count in tqdm(pruned_vs, desc="Resolving components"):
-
         component_time_start = time.time()
 
         my_genomic_paths = []
@@ -191,7 +193,6 @@ def main():
 
         # Case 2 components
         if len(candidate_nodes) == 2:
-
             all_self_looped = True
 
             for node in candidate_nodes:
@@ -199,7 +200,6 @@ def main():
                     all_self_looped = False
 
             if all_self_looped:
-
                 case2_found.add(my_count)
 
                 cycle_components.add(my_count)
@@ -218,7 +218,6 @@ def main():
                         unitig2 = candidate_nodes[target_vertex_id]
 
                 if unitig1 != "" and unitig2 != "":
-
                     unitig1_name = unitig_names[unitig1]
                     unitig2_name = unitig_names[unitig2]
 
@@ -243,7 +242,6 @@ def main():
                         repeat_unitig_name = unitig1_name
 
                     if unitig_to_consider != -1:
-
                         cycle_number = 1
                         resolved_edges.add(unitig_to_consider)
                         resolved_edges.add(repeat_unitig)
@@ -277,7 +275,6 @@ def main():
 
         # Case 3 components
         elif len(candidate_nodes) > 2 and len(candidate_nodes) <= compcount:
-
             # Create initial directed graph with coverage values
             # ----------------------------------------------------------------------
             G_edge = nx.DiGraph()
@@ -292,14 +289,12 @@ def main():
             clean_node_count = 0
 
             for vertex in pruned_graph.vs["id"]:
-
                 unitig_name = unitig_names[vertex]
 
                 if unitig_name not in self_looped_nodes:
                     clean_node_count += 1
 
                 for node in oriented_links[unitig_name]:
-
                     consider_edge = False
 
                     if not (
@@ -308,7 +303,6 @@ def main():
                         consider_edge = True
 
                     if consider_edge:
-
                         cov_1 = MAX_VAL
                         cov_2 = MAX_VAL
 
@@ -342,7 +336,6 @@ def main():
                 logger.debug(f"No cycles found in component {my_count}")
 
             if has_cycles:
-
                 logger.debug(
                     f"Potentially cycles can be detected in component {my_count}."
                 )
@@ -352,7 +345,6 @@ def main():
                 dead_ends_to_remove = edge_graph_utils.remove_dead_ends(G_edge)
 
                 if len(dead_ends_to_remove) > 0:
-
                     for node in dead_ends_to_remove:
                         node_id = unitig_names_rev[node[:-1]]
                         if node_id in candidate_nodes:
@@ -377,7 +369,6 @@ def main():
                 )
 
                 if len(source_sink_candidates) > 0:
-
                     # Identify the longest source/sink vertex
                     max_length = -1
                     max_length_vertex = -1
@@ -403,7 +394,6 @@ def main():
                 G = nx.DiGraph()
 
                 for u, v, cov in G_edge.edges(data=True):
-
                     if u not in node_indices:
                         node_indices[u] = my_counter
                         node_indices_rev[my_counter] = u
@@ -421,7 +411,6 @@ def main():
                 out_degree = []
 
                 for node in list(G.nodes):
-
                     if node_indices_rev[node][:-1] not in self_looped_nodes:
                         clean_indegree = len(
                             [
@@ -461,7 +450,6 @@ def main():
                 visited_edges = []
 
                 for u, v, cov in G_edge.edges(data=True):
-
                     u_name = unitig_names_rev[u[:-1]]
                     v_name = unitig_names_rev[v[:-1]]
 
@@ -505,13 +493,7 @@ def main():
                             v_index,
                             u_index,
                         ) not in visited_edges:
-                            
-                            cov_upper_bound = 0
-
-                            if cov["weight"] > 0:
-                                cov_upper_bound = cov["weight"]
-                            else:
-                                cov_upper_bound = mincov
+                            cov_upper_bound = cov["weight"]
 
                             if juction_cov <= cov_upper_bound:
                                 network_edges.append(
@@ -547,7 +529,6 @@ def main():
                 # Iterate through solution paths
                 # ----------------------------------------------------------------------
                 if len(solution_paths) != 0:
-
                     phage_like_edges = phage_like_edges.union(
                         set(original_candidate_nodes)
                     )
@@ -557,9 +538,10 @@ def main():
                     for solution_path in solution_paths:
                         coverage_val = solution_paths[solution_path]["weight"]
 
+                        logger.debug(f"Path {cycle_number} coverage: {coverage_val}")
+
                         # Filter path by coverage
                         if coverage_val >= mincov:
-
                             # Create graph for path
                             G_path = nx.DiGraph()
 
@@ -570,14 +552,12 @@ def main():
                             )
 
                             if 0 in list(G_path.nodes):
-
                                 # Get all simple paths from node 0 to last node
                                 candidate_paths = list(
                                     nx.all_simple_paths(G_path, 0, len(candidate_nodes))
                                 )
 
                                 if len(candidate_paths) > 0:
-
                                     logger.debug(
                                         f"candidate_paths: {candidate_paths[0]}"
                                     )
@@ -633,9 +613,11 @@ def main():
                                     cycle_number += 1
 
                     logger.debug(f"Number of paths selected: {cycle_number-1}")
-                    resolved_components.add(my_count)
-                    resolved_cyclic.add(my_count)
-                    case3_resolved.add(my_count)
+
+                    if cycle_number > 1:
+                        resolved_components.add(my_count)
+                        resolved_cyclic.add(my_count)
+                        case3_resolved.add(my_count)
 
                 else:
                     logger.debug(f"No paths detected")
@@ -646,7 +628,6 @@ def main():
 
         # Case 1 components - circular unitigs
         elif len(candidate_nodes) == 1:
-
             case1_found.add(my_count)
 
             unitig_name = unitig_names[candidate_nodes[0]]
@@ -690,7 +671,6 @@ def main():
         n_paths = 0
 
         if len(my_genomic_paths) > 1:
-
             # Get the degree of the component
             graph_degree = assembly_graph.degree(original_candidate_nodes)
 
@@ -701,9 +681,7 @@ def main():
 
             # Filter genomic paths
             for genomic_path in my_genomic_paths:
-
                 if genomic_path.length > largest_length * 0.95:
-
                     logger.debug(
                         f"{genomic_path.id}\t{genomic_path.length}\t{genomic_path.coverage}"
                     )
@@ -727,7 +705,6 @@ def main():
                 and len(in_degree) > 0
                 and len(out_degree) > 0
             ):
-
                 # Create GenomeComponent object with component details
                 genome_comp = GenomeComponent(
                     f"phage_comp_{my_count}",
@@ -815,6 +792,11 @@ def main():
     filename = write_component_info(all_components, output)
     logger.info(f"Resolved component information can be found in {output}/{filename}")
 
+    filename = write_component_phrog_info(resolved_components, comp_phrogs, output)
+    logger.info(
+        f"PHROGs found in resolved components can be found in {output}/{filename}"
+    )
+
     # Get elapsed time
     # ----------------------------------------------------------------------
 
